@@ -58,16 +58,12 @@ class DiscreteEnv(gym.Env):
                                    high=self.max_Xas, 
                                    dtype=np.float32)
     
-    #self.Y_obs_space = spaces.Discrete(n=2)
-    #combine them in a tuple - I think it doesn't work well
-    #self.observation_space = spaces.Tuple([self.Xas_obs_space, self.Y_obs_space])
-
-    #set an initial state, sample a random row from df to get 1 observation (Xs(0), Xa(0))
+    #set an initial state
     #the step def will update self.state according to some value
     self.state=None    #self.df.sample(n=1, random_state=1).values.reshape(3,)
 
     #introduce some (short) length (time steps)
-    #self.horizon=20
+    self.horizon=20
     
     
 
@@ -115,13 +111,17 @@ class DiscreteEnv(gym.Env):
     #self.horizon -= 1
     
     #depending on the value of self.state, apply a reward
-    done = bool(self.Ynew_cumul < 0.2)    
-    reward = 0
+    #done = np.any(Prob1 < 0.2)    
+    #reward = 0
     
-    if done:
-      reward = self.Ynew_cumul 
+    #if done:
+      #reward = self.Ynew_cumul 
     
-  
+    done = bool(self.horizon <= 0)
+    if done=True:
+      reward = self.Ynew_cumul
+    else:
+      done = False 
     
     
     #check if horion is over, otherwise keep on doing
@@ -138,7 +138,7 @@ class DiscreteEnv(gym.Env):
 #reset state and horizon    
   def reset(self):
     self.state= self.df.sample(n=1, random_state=1).values.reshape(3,) 
-    #self.horizon = 20
+    self.horizon = 20
     return self.state
 
 
